@@ -1,7 +1,7 @@
 /*
 
 This is a generic program misc functions class v1.0.
-Copyright  1997,2002,2003,2004 Jaakko Hyvtti
+Copyright  1997,2002,2003,2004,2008 Jaakko Hyvtti
 
 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License version 2 as
@@ -27,9 +27,11 @@ Email address above.
 
 */
 
+#include <cstdlib>
 #include <iostream>
 #include <string>
 
+#include <string.h>
 #include <unistd.h>
 #include <sysexits.h>
 #include <sys/ioctl.h>
